@@ -137,6 +137,8 @@ log.addHandler(logging.NullHandler())
 # Constants
 # =============================================================================
 
+AVAILABILITY = 'availability'
+CONVERTER = 'converter'
 DEFAULT_WIDTH = 120
 DEFAULT_MIN_COL_WIDTH = 15
 ENCODING = "utf-8"
@@ -205,7 +207,9 @@ def get_filelikeobject(filename: str = None,
         return io.BytesIO(blob)
 
 
-def get_file_contents(filename: str = None, blob: bytes = None) -> bytes:
+# noinspection PyUnusedLocal
+def get_file_contents(filename: str = None, blob: bytes = None,
+                      **kwargs) -> bytes:
     """Returns binary contents of a file, or blob."""
     if not filename and not blob:
         raise ValueError("no filename and no blob")
@@ -815,56 +819,56 @@ ext_map = {
     # Converter functions must be of the form func(filename, blob, **kwargs):
     # Availability must be either a boolean or a function that takes no params.
     '.doc': {
-        'converter': convert_doc_to_text,
-        'availability': availability_doc,
+        CONVERTER: convert_doc_to_text,
+        AVAILABILITY: availability_doc,
     },
     '.dot': {
-        'converter': convert_doc_to_text,
-        'availability': availability_doc,
+        CONVERTER: convert_doc_to_text,
+        AVAILABILITY: availability_doc,
     },
     '.docm': {
-        'converter': convert_docx_to_text,
-        'availability': True,
+        CONVERTER: convert_docx_to_text,
+        AVAILABILITY: True,
     },
     '.docx': {
-        'converter': convert_docx_to_text,
-        'availability': True,
+        CONVERTER: convert_docx_to_text,
+        AVAILABILITY: True,
     },
     '.html': {
-        'converter': convert_html_to_text,
-        'availability': True,
+        CONVERTER: convert_html_to_text,
+        AVAILABILITY: True,
     },
     '.htm': {
-        'converter': convert_html_to_text,
-        'availability': True,
+        CONVERTER: convert_html_to_text,
+        AVAILABILITY: True,
     },
     '.log': {
-        'converter': get_file_contents,
-        'availability': True,
+        CONVERTER: get_file_contents,
+        AVAILABILITY: True,
     },
     '.odt': {
-        'converter': convert_odt_to_text,
-        'availability': True,
+        CONVERTER: convert_odt_to_text,
+        AVAILABILITY: True,
     },
     '.pdf': {
-        'converter': convert_pdf_to_txt,
-        'availability': availability_pdf,
+        CONVERTER: convert_pdf_to_txt,
+        AVAILABILITY: availability_pdf,
     },
     '.rtf': {
-        'converter': convert_rtf_to_text,
-        'availability': availability_rtf,
+        CONVERTER: convert_rtf_to_text,
+        AVAILABILITY: availability_rtf,
     },
     '.xml': {
-        'converter': convert_xml_to_text,
-        'availability': True,
+        CONVERTER: convert_xml_to_text,
+        AVAILABILITY: True,
     },
     '.txt': {
-        'converter': get_file_contents,
-        'availability': True,
+        CONVERTER: get_file_contents,
+        AVAILABILITY: True,
     },
     None: {  # fallback
-        'converter': convert_anything_to_text,
-        'availability': availability_anything,
+        CONVERTER: convert_anything_to_text,
+        AVAILABILITY: availability_anything,
     },
 }
 
@@ -908,7 +912,7 @@ def document_to_text(filename: str = None,
         log.warning("Unknown filetype: {}; using generic tool".format(
             extension))
         info = ext_map[None]
-    func = info['converter']
+    func = info[CONVERTER]
     kwargs = {
         'plain': plain,
         'width': width,
@@ -923,7 +927,7 @@ def is_text_extractor_available(extension: str) -> bool:
     info = ext_map.get(extension)
     if info is None:
         return False
-    availability = info['availability']
+    availability = info[AVAILABILITY]
     if type(availability) == bool:
         return availability
     elif callable(availability):
