@@ -57,7 +57,7 @@ AttrDict's disadvantages are:
 
 Plain old objects:
 - not immutable
-- no dictionary access
+- no dictionary access -- though can use getattr()
 - but otherwise simpler than enums
 
 LowerCaseAutoStringObject:
